@@ -54,7 +54,7 @@ class LogPlayerAttack(Event):
         super().from_dict()
         self.attack_id = self._data.get('attackId')
         self.attacker = objects.Character(self._data.get('attacker', {}))
-        self.attacker_type = self._data.get('attackerType')
+        self.attack_type = self._data.get('attackType')
         self.weapon = objects.Item(self._data.get('weapon', {}))
         self.vehicle = objects.Vehicle(self._data.get('vehicle', {}))
 
@@ -65,7 +65,7 @@ class LogPlayerTakeDamage(Event):
         super().from_dict()
         self.attack_id = self._data.get('attackId')
         self.attacker = objects.Character(self._data.get('attacker', {}))
-        self.victim = objects.Character(self._data.get('victm', {}))
+        self.victim = objects.Character(self._data.get('victim', {}))
         self.damage_type_category = self._data.get('damageTypeCategory')
         self.damage_reason = self._data.get('damageReason')
         self.damage = self._data.get('damage')
@@ -134,7 +134,7 @@ class LogVehicle(Event):
     def from_dict(self):
         super().from_dict()
         self.character = objects.Character(self._data.get('character', {}))
-        self.item = objects.Item(self._data.get('item', {}))
+        self.vehicle = objects.Vehicle(self._data.get('vehicle', {}))
 
 
 class LogVehicleRide(LogVehicle):
